@@ -1,4 +1,4 @@
-from flask import Flask, render_template, jsonify, request, send_from_directory
+from flask import Flask, jsonify, request, send_from_directory
 from flask_cors import CORS
 import json
 import os
@@ -11,7 +11,7 @@ from dotenv import load_dotenv
 # Import version from package
 from . import __version__
 from .preprocessing import preprocess_antismash_files
-from .data_loader import load_json_file, load_specific_record
+from .data_loader import load_specific_record
 from .file_utils import match_location
 from .database import check_database_exists, get_database_entries
 
@@ -19,8 +19,8 @@ from .database import check_database_exists, get_database_entries
 load_dotenv()
 
 # Configuration: Determine if running in public or local mode
-# PUBLIC mode (default): Restricted access, no filesystem browsing, fixed data directory
-# LOCAL mode: Full access to filesystem, preprocessing, etc.
+# PUBLIC mode: Restricted access, no filesystem browsing, fixed data directory
+# LOCAL mode (default): Full access to filesystem, preprocessing, etc.
 PUBLIC_MODE = os.getenv('BGCV_PUBLIC_MODE', 'false').lower() == 'true'
 
 # Get the directory where this module is installed
@@ -50,19 +50,20 @@ else:
 
 # Global variable to store currently loaded data
 ANTISMASH_DATA = None
-CURRENT_FILE = None #TODO: check if we are using this, and whether it stores session-related data
 
 # Global variable to store current database path
 CURRENT_DATABASE_PATH = None
 
-# Define the data directory based on mode
-DATA_DIRECTORY: Optional[Path]
+# Define the restricted data directory based on mode
+# In PUBLIC mode: Path object restricting access to a specific directory
+# In LOCAL mode: None indicates unrestricted filesystem access
+RESTRICTED_DATA_DIRECTORY: Optional[Path]
 if PUBLIC_MODE:
     # In public mode, use a fixed data directory (can be configured)
-    DATA_DIRECTORY = Path(os.getenv('BGCV_DATA_DIR', 'data')).resolve()
+    RESTRICTED_DATA_DIRECTORY = Path(os.getenv('BGCV_DATA_DIR', 'data')).resolve()
 else:
-    # In local mode, no fixed directory restriction
-    DATA_DIRECTORY = None
+    # In local mode, no directory restriction - users can access any path
+    RESTRICTED_DATA_DIRECTORY = None
 
 # Global variables for preprocessing status
 PREPROCESSING_STATUS = {
@@ -105,10 +106,18 @@ def spa_fallback(path):
 @app.route('/api/status')
 def get_status():
     """API endpoint to get current file and data loading status."""
+    # Determine the current data directory
+    current_data_dir = None
+    if CURRENT_DATABASE_PATH:
+        # Use the folder containing the current database
+        current_data_dir = str(Path(CURRENT_DATABASE_PATH).parent)
+    elif PUBLIC_MODE and RESTRICTED_DATA_DIRECTORY:
+        # In public mode, use the configured data directory
+        current_data_dir = str(RESTRICTED_DATA_DIRECTORY)
+    
     return jsonify({
-        "current_file": CURRENT_FILE if CURRENT_FILE else None,
         "has_loaded_data": ANTISMASH_DATA is not None,
-        "data_directory_exists": Path("data").exists(),
+        "current_data_directory": current_data_dir,
         "public_mode": PUBLIC_MODE
     })
 
@@ -252,16 +261,16 @@ def load_database_entry():
             data_dir = str(db_folder)
         else:
             # Fallback: Look for the file in the data directory
-            if PUBLIC_MODE and DATA_DIRECTORY:
-                data_dir = str(DATA_DIRECTORY)
+            if PUBLIC_MODE and RESTRICTED_DATA_DIRECTORY:
+                data_dir = str(RESTRICTED_DATA_DIRECTORY)
             else:
                 data_dir = "data"
             file_path = Path(data_dir) / filename
         
         # In public mode, ensure file is within allowed directory
-        if PUBLIC_MODE and DATA_DIRECTORY:
+        if PUBLIC_MODE and RESTRICTED_DATA_DIRECTORY:
             try:
-                file_path.resolve().relative_to(DATA_DIRECTORY)
+                file_path.resolve().relative_to(RESTRICTED_DATA_DIRECTORY)
             except ValueError:
                 return jsonify({"error": "Access denied: File must be within the data directory"}), 403
         
@@ -275,16 +284,14 @@ def load_database_entry():
             return jsonify({"error": f"Record {record_id} not found in {filename}"}), 404
         
         # Set global data
-        global ANTISMASH_DATA, CURRENT_FILE
+        global ANTISMASH_DATA
         ANTISMASH_DATA = modified_data
-        CURRENT_FILE = f"{filename}:{record_id}"
         
         # Get the loaded record info
         loaded_record = modified_data["records"][0] if modified_data["records"] else {}
         
         return jsonify({
             "message": f"Successfully loaded {filename}:{record_id}",
-            "current_file": CURRENT_FILE,
             "filename": filename,
             "record_id": record_id,
             "record_info": {
@@ -299,54 +306,6 @@ def load_database_entry():
     except Exception as e:
         return jsonify({"error": f"Failed to load entry: {str(e)}"}), 500
 
-@app.route('/api/info')
-def get_info():
-    """API endpoint to get basic information about the dataset."""
-    if not ANTISMASH_DATA:
-        return jsonify({
-            "error": "No AntiSMASH data loaded",
-            "version": None,
-            "total_records": 0,
-            "current_file": None
-        }), 200
-    
-    return jsonify({
-        "version": ANTISMASH_DATA.get("version"),
-        "input_file": ANTISMASH_DATA.get("input_file"),
-        "taxon": ANTISMASH_DATA.get("taxon"),
-        "total_records": len(ANTISMASH_DATA.get("records", [])),
-        "schema": ANTISMASH_DATA.get("schema"),
-        "current_file": CURRENT_FILE
-    })
-
-@app.route('/api/records')
-def get_records():
-    """API endpoint to get list of all records (regions)."""
-    if not ANTISMASH_DATA:
-        return jsonify({"error": "AntiSMASH data not found"}), 404
-    
-    records = []
-    for record in ANTISMASH_DATA.get("records", []):
-        records.append({
-            "id": record.get("id"),
-            "description": record.get("description"),
-            "gc_content": record.get("gc_content"),
-            "feature_count": len(record.get("features", []))
-        })
-    
-    return jsonify(records)
-
-@app.route('/api/records/<record_id>')
-def get_record(record_id):
-    """API endpoint to get a specific record."""
-    if not ANTISMASH_DATA:
-        return jsonify({"error": "AntiSMASH data not found"}), 404
-    
-    record = next((r for r in ANTISMASH_DATA.get("records", []) if r.get("id") == record_id), None)
-    if record:
-        return jsonify(record)
-    return jsonify({"error": "Record not found"}), 404
-
 @app.route('/api/records/<record_id>/regions')
 def get_record_regions(record_id):
     """API endpoint to get all regions for a specific record."""
@@ -471,49 +430,6 @@ def get_record_features(record_id):
         "features": features
     })
 
-@app.route('/api/feature-types')
-def get_feature_types():
-    """API endpoint to get all available feature types across all records."""
-    if not ANTISMASH_DATA:
-        return jsonify({"error": "AntiSMASH data not found"}), 404
-    
-    feature_types = set()
-    for record in ANTISMASH_DATA.get("records", []):
-        for feature in record.get("features", []):
-            if "type" in feature:
-                feature_types.add(feature["type"])
-    
-    return jsonify(sorted(list(feature_types)))
-
-@app.route('/api/stats')
-def get_stats():
-    """API endpoint to get statistics about the dataset."""
-    if not ANTISMASH_DATA:
-        return jsonify({"error": "AntiSMASH data not found"}), 404
-    
-    # Calculate statistics
-    records = ANTISMASH_DATA.get("records", [])
-    total_features = sum(len(r.get("features", [])) for r in records)
-    
-    feature_type_counts = {}
-    for record in records:
-        for feature in record.get("features", []):
-            ftype = feature.get("type", "unknown")
-            feature_type_counts[ftype] = feature_type_counts.get(ftype, 0) + 1
-    
-    return jsonify({
-        "total_records": len(records),
-        "total_features": total_features,
-        "feature_types": feature_type_counts,
-        "version": ANTISMASH_DATA.get("version"),
-        "schema": ANTISMASH_DATA.get("schema")
-    })
-
-@app.route('/api/health')
-def health_check():
-    """Health check endpoint."""
-    return jsonify({"status": "healthy", "message": "Server is running"})
-
 @app.route('/api/version')
 def get_version():
     """API endpoint to get the application version."""
@@ -588,8 +504,8 @@ def get_database_entries_endpoint():
     db_path = CURRENT_DATABASE_PATH
     if not db_path or not Path(db_path).exists():
         # Fallback: Look for attributes.db in the data directory
-        if PUBLIC_MODE and DATA_DIRECTORY:
-            data_dir = DATA_DIRECTORY
+        if PUBLIC_MODE and RESTRICTED_DATA_DIRECTORY:
+            data_dir = RESTRICTED_DATA_DIRECTORY
         else:
             data_dir = Path("data")
         fallback_db_path = data_dir / "attributes.db"
@@ -617,6 +533,7 @@ if not PUBLIC_MODE:
         
         data = request.get_json()
         folder_path = data.get('path')
+        selected_files = data.get('files')  # Optional list of file paths
         
         if not folder_path:
             return jsonify({"error": "No folder path provided"}), 400
@@ -627,30 +544,42 @@ if not PUBLIC_MODE:
             if not resolved_path.exists() or not resolved_path.is_dir():
                 return jsonify({"error": "Invalid folder path"}), 400
             
-            # Count JSON files
-            json_files = list(resolved_path.glob("*.json"))
-            if not json_files:
-                return jsonify({"error": "No JSON files found in the folder"}), 400
+            # Determine which files to process
+            json_files_to_process = None
+            
+            if selected_files and len(selected_files) > 0:
+                # Use the selected files
+                json_files_to_process = [Path(f) for f in selected_files if Path(f).suffix == '.json' and Path(f).exists()]
+                if not json_files_to_process:
+                    return jsonify({"error": "None of the selected files are valid JSON files"}), 400
+                total_count = len(json_files_to_process)
+            else:
+                # Fallback to all JSON files in the folder (recursive scan)
+                all_json_files = list(resolved_path.rglob("*.json"))[:5000]
+                if not all_json_files:
+                    return jsonify({"error": "No JSON files found in the folder"}), 400
+                json_files_to_process = all_json_files
+                total_count = len(all_json_files)
             
             # Reset status
             PREPROCESSING_STATUS.update({
                 'is_running': True,
                 'current_file': None,
                 'files_processed': 0,
-                'total_files': len(json_files),
+                'total_files': total_count,
                 'status': 'running',
                 'error_message': None,
                 'folder_path': str(resolved_path)
             })
             
             # Start preprocessing in background thread
-            thread = threading.Thread(target=run_preprocessing, args=(str(resolved_path),))
+            thread = threading.Thread(target=run_preprocessing, args=(str(resolved_path), json_files_to_process))
             thread.daemon = True
             thread.start()
             
             return jsonify({
                 "message": "Preprocessing started",
-                "total_files": len(json_files),
+                "total_files": total_count,
                 "folder_path": str(resolved_path)
             })
             
@@ -663,8 +592,13 @@ def get_preprocessing_status():
     """Get the current preprocessing status."""
     return jsonify(PREPROCESSING_STATUS)
 
-def run_preprocessing(folder_path):
-    """Run the preprocessing function in a background thread."""
+def run_preprocessing(folder_path, json_files=None):
+    """Run the preprocessing function in a background thread.
+    
+    Args:
+        folder_path: Path to the folder to preprocess
+        json_files: Optional list of specific JSON file paths to process
+    """
     global PREPROCESSING_STATUS
     
     def progress_callback(current_file, files_processed, total_files):
@@ -677,7 +611,7 @@ def run_preprocessing(folder_path):
     
     try:
         # Run the preprocessing function
-        results = preprocess_antismash_files(folder_path, progress_callback)
+        results = preprocess_antismash_files(folder_path, progress_callback, json_files)
         
         # Update status on completion
         PREPROCESSING_STATUS.update({
@@ -695,25 +629,6 @@ def run_preprocessing(folder_path):
             'error_message': str(e)
         })
 
-@app.route('/api/debug/static-files')
-def debug_static_files():
-    """Debug endpoint to check what static files are available."""
-    static_dir = Path(app.static_folder)
-    
-    result = {
-        "static_folder": str(static_dir),
-        "static_folder_exists": static_dir.exists(),
-        "files": []
-    }
-    
-    if static_dir.exists():
-        for file_path in static_dir.rglob('*'):
-            if file_path.is_file():
-                result["files"].append(str(file_path.relative_to(static_dir)))
-    
-    result["files"] = sorted(result["files"])
-    return jsonify(result)
-
 @app.errorhandler(404)
 def not_found(error):
     """Handle 404 errors."""
@@ -731,7 +646,7 @@ def main():
     print(f"Running in {'PUBLIC' if PUBLIC_MODE else 'LOCAL'} mode")
     
     if PUBLIC_MODE:
-        print(f"Data directory: {DATA_DIRECTORY}")
+        print(f"Data directory: {RESTRICTED_DATA_DIRECTORY}")
         print("Restricted endpoints: /api/browse, /api/scan-folder, /api/preprocess-folder, /api/check-index, /api/set-database-path")
 
     host = os.environ.get('BGCV_HOST', 'localhost')
